package com.huijy.management.service;

import java.util.List;

import com.huijy.management.domain.Shop;

/**
 * 商铺管理Service接口
 *
 * @author luobo
 * @date 2021-09-12
 */
public interface IShopService {
    /**
     * 查询商铺管理
     *
     * @param shopId 商铺管理主键
     * @return 商铺管理
     */
    public Shop selectShopByShopId(Long shopId);

    /**
     * 查询商铺管理列表
     *
     * @param shop 商铺管理
     * @return 商铺管理集合
     */
    public List<Shop> selectShopList(Shop shop);

    /**
     * 新增商铺管理
     *
     * @param shop 商铺管理
     * @return 结果
     */
    public int insertShop(Shop shop);

    /**
     * 修改商铺管理
     *
     * @param shop 商铺管理
     * @return 结果
     */
    public int updateShop(Shop shop);

    /**
     * 批量删除商铺管理
     *
     * @param shopIds 需要删除的商铺管理主键集合
     * @return 结果
     */
    public int deleteShopByShopIds(Long[] shopIds);

    /**
     * 删除商铺管理信息
     *
     * @param shopId 商铺管理主键
     * @return 结果
     */
    public int deleteShopByShopId(Long shopId);

    /**
     * 根据会员id获取会员店铺列表
     *
     * @param memberId
     * @return
     */
    List<Shop> getListByMemberId(Long memberId);

    public List<Shop> selectShopByHotel();
}
